# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.frame
import typing
import uno
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .dispatch_information import DispatchInformation as DispatchInformation_1a290ec9

class XDispatchInformationProvider(XInterface_8f010a43):
    """
    provides information about supported commands
    
    This interface can be used to retrieve additional information about supported commands. This interface is normally used by configuration implementations to retrieve all supported commands. A dispatch information provider is normally supported by a Frame service.
    
    **since**
    
        OOo 2.0

    See Also:
        `API XDispatchInformationProvider <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1frame_1_1XDispatchInformationProvider.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.frame'
    __ooo_full_ns__: str = 'com.sun.star.frame.XDispatchInformationProvider'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.frame.XDispatchInformationProvider'

    @abstractmethod
    def getConfigurableDispatchInformation(self, CommandGroup: int) -> 'typing.Tuple[DispatchInformation_1a290ec9, ...]':
        """
        returns additional information about supported commands of a given command group.
        """
        ...
    @abstractmethod
    def getSupportedCommandGroups(self) -> uno.ByteSequence:
        """
        returns all supported command groups.
        """
        ...

__all__ = ['XDispatchInformationProvider']




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.i18n
from enum import IntEnum
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    from ooo.helper.enum_helper import UnoConstMeta, ConstEnumMeta

    class TransliterationModulesExtra(metaclass=UnoConstMeta, type_name="com.sun.star.i18n.TransliterationModulesExtra", name_space="com.sun.star.i18n"):
        """Dynamic Class. Contains all the constant values of ``com.sun.star.i18n.TransliterationModulesExtra``"""
        pass

    class TransliterationModulesExtraEnum(IntEnum, metaclass=ConstEnumMeta, type_name="com.sun.star.i18n.TransliterationModulesExtra", name_space="com.sun.star.i18n"):
        """Dynamic Enum. Contains all the constant values of ``com.sun.star.i18n.TransliterationModulesExtra`` as Enum values"""
        pass

else:
    from ...lo.i18n.transliteration_modules_extra import TransliterationModulesExtra as TransliterationModulesExtra

    class TransliterationModulesExtraEnum(IntEnum):
        """
        Enum of Const Class TransliterationModulesExtra

        Extra transliteration module enumeration to use with XTransliteration.loadModule()
        
        The values used in this group need to be different from the ones in TransliterationModules and TransliterationModulesNew!
        """
        SENTENCE_CASE = TransliterationModulesExtra.SENTENCE_CASE
        """
        The first character of the sentence is put in upper case.
        """
        TITLE_CASE = TransliterationModulesExtra.TITLE_CASE
        """
        The first character of the word is put in upper case.
        
        This one is part
        """
        TOGGLE_CASE = TransliterationModulesExtra.TOGGLE_CASE
        """
        All characters of the word are to change their case from small letters to capital letters and vice versa.
        """
        IGNORE_DIACRITICS_CTL = TransliterationModulesExtra.IGNORE_DIACRITICS_CTL
        """
        Ignore diacritics.
        
        Despite the _CTL name suffix this is not only about CTL/Arabic diacritic characters, though these are handled as well, but the transliteration decomposes and removes any diacritic from characters.
        
        Because we cannot extend the TransliterationModules enum we use TransliterationModulesExtra and it will act the same way.
        """
        IGNORE_KASHIDA_CTL = TransliterationModulesExtra.IGNORE_KASHIDA_CTL
        """
        Ignore Kashida mark.
        """
        END_OF_MODULE = TransliterationModulesExtra.END_OF_MODULE

__all__ = ['TransliterationModulesExtra', 'TransliterationModulesExtraEnum']



# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.xml.crypto
from enum import IntEnum
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    from ooo.helper.enum_helper import UnoConstMeta, ConstEnumMeta

    class DigestID(metaclass=UnoConstMeta, type_name="com.sun.star.xml.crypto.DigestID", name_space="com.sun.star.xml.crypto"):
        """Dynamic Class. Contains all the constant values of ``com.sun.star.xml.crypto.DigestID``"""
        pass

    class DigestIDEnum(IntEnum, metaclass=ConstEnumMeta, type_name="com.sun.star.xml.crypto.DigestID", name_space="com.sun.star.xml.crypto"):
        """Dynamic Enum. Contains all the constant values of ``com.sun.star.xml.crypto.DigestID`` as Enum values"""
        pass

else:
    from ....lo.xml.crypto.digest_id import DigestID as DigestID

    class DigestIDEnum(IntEnum):
        """
        Enum of Const Class DigestID

        The constant set contains identifiers of supported digest-creation algorithms.
        
        **since**
        
            OOo 3.4
        """
        SHA1 = DigestID.SHA1
        """
        identifier of SHA-1 algorithm
        """
        SHA256 = DigestID.SHA256
        """
        identifier of SHA-256 algorithm
        """
        SHA1_1K = DigestID.SHA1_1K
        """
        identifier of SHA-1 algorithm that is applied to the first kilobyte of data.
        """
        SHA256_1K = DigestID.SHA256_1K
        """
        identifier of SHA-256 algorithm that is applied to the first kilobyte of data.
        """
        SHA512 = DigestID.SHA512
        """
        identifier of SHA-512 algorithm
        
        **since**
        
            LibreOffice 6.0
        """
        SHA512_1K = DigestID.SHA512_1K
        """
        identifier of SHA-512 algorithm that is applied to the first kilobyte of data.
        
        **since**
        
            LibreOffice 6.0
        """

__all__ = ['DigestID', 'DigestIDEnum']



# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sdb
from abc import abstractproperty
from ..beans.x_property_set import XPropertySet as XPropertySet_bc180bfa
from .single_select_query_analyzer import SingleSelectQueryAnalyzer as SingleSelectQueryAnalyzer_577c105f
from .x_single_select_query_composer import XSingleSelectQueryComposer as XSingleSelectQueryComposer_66e310b9

class SingleSelectQueryComposer(SingleSelectQueryAnalyzer_577c105f, XPropertySet_bc180bfa, XSingleSelectQueryComposer_66e310b9):
    """
    Service Class

    represents a service for composing a single select statement.
    
    It hides the complexity of parsing and evaluating a single select statement and provides sophisticated methods for expanding a statement with filter, group by, having and order criteria. To get the new extended statement use the methods from com.sun.star.sdb.SingleSelectQueryAnalyzer.
    
    A SingleSelectQueryComposer is usually obtained from a Connection using the com.sun.star.lang.XMultiServiceFactory interface.

    See Also:
        `API SingleSelectQueryComposer <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1sdb_1_1SingleSelectQueryComposer.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sdb'
    __ooo_full_ns__: str = 'com.sun.star.sdb.SingleSelectQueryComposer'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def Original(self) -> str:
        """
        is the original SQL statement set with the interface com.sun.star.sdb.XSingleSelectQueryAnalyzer.
        """
        ...



__all__ = ['SingleSelectQueryComposer']




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from ....dyn.form.runtime.feature_state import FeatureState as FeatureState
from ....dyn.form.runtime.filter_event import FilterEvent as FilterEvent
from ....dyn.form.runtime.form_controller import FormController as FormController
from ....dyn.form.runtime.form_feature import FormFeature as FormFeature
from ....dyn.form.runtime.form_feature import FormFeatureEnum as FormFeatureEnum
from ....dyn.form.runtime.form_operations import FormOperations as FormOperations
from ....dyn.form.runtime.x_feature_invalidation import XFeatureInvalidation as XFeatureInvalidation
from ....dyn.form.runtime.x_filter_controller import XFilterController as XFilterController
from ....dyn.form.runtime.x_filter_controller_listener import XFilterControllerListener as XFilterControllerListener
from ....dyn.form.runtime.x_form_controller import XFormController as XFormController
from ....dyn.form.runtime.x_form_controller_context import XFormControllerContext as XFormControllerContext
from ....dyn.form.runtime.x_form_operations import XFormOperations as XFormOperations



# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.frame
from enum import IntEnum
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    from ooo.helper.enum_helper import UnoConstMeta, ConstEnumMeta

    class InfobarType(metaclass=UnoConstMeta, type_name="com.sun.star.frame.InfobarType", name_space="com.sun.star.frame"):
        """Dynamic Class. Contains all the constant values of ``com.sun.star.frame.InfobarType``"""
        pass

    class InfobarTypeEnum(IntEnum, metaclass=ConstEnumMeta, type_name="com.sun.star.frame.InfobarType", name_space="com.sun.star.frame"):
        """Dynamic Enum. Contains all the constant values of ``com.sun.star.frame.InfobarType`` as Enum values"""
        pass

else:
    from ...lo.frame.infobar_type import InfobarType as InfobarType

    class InfobarTypeEnum(IntEnum):
        """
        Enum of Const Class InfobarType

        Infobar types.
        
        **since**
        
            LibreOffice 6.4
        """
        INFO = InfobarType.INFO
        """
        For information messages (color: light blue).
        """
        SUCCESS = InfobarType.SUCCESS
        """
        For success notifications (color: light green).
        """
        WARNING = InfobarType.WARNING
        """
        For warning messages (color: orange).
        """
        DANGER = InfobarType.DANGER
        """
        For critical errors (color: red).
        """

__all__ = ['InfobarType', 'InfobarTypeEnum']



# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from ....lo.sdb.tools.composition_type import CompositionType as CompositionType
from ....lo.sdb.tools.connection_tools import ConnectionTools as ConnectionTools
from ....lo.sdb.tools.x_connection_supplier import XConnectionSupplier as XConnectionSupplier
from ....lo.sdb.tools.x_connection_tools import XConnectionTools as XConnectionTools
from ....lo.sdb.tools.x_data_source_meta_data import XDataSourceMetaData as XDataSourceMetaData
from ....lo.sdb.tools.x_index_alteration import XIndexAlteration as XIndexAlteration
from ....lo.sdb.tools.x_key_alteration import XKeyAlteration as XKeyAlteration
from ....lo.sdb.tools.x_object_names import XObjectNames as XObjectNames
from ....lo.sdb.tools.x_table_alteration import XTableAlteration as XTableAlteration
from ....lo.sdb.tools.x_table_name import XTableName as XTableName
from ....lo.sdb.tools.x_table_rename import XTableRename as XTableRename
from ....lo.sdb.tools.x_view_access import XViewAccess as XViewAccess



# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.lang
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..uno.x_component_context import XComponentContext as XComponentContext_e2e10d4a

class XMultiComponentFactory(XInterface_8f010a43):
    """
    Factory interface for creating component instances giving a context from which to retrieve deployment values.

    See Also:
        `API XMultiComponentFactory <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1lang_1_1XMultiComponentFactory.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.lang'
    __ooo_full_ns__: str = 'com.sun.star.lang.XMultiComponentFactory'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.lang.XMultiComponentFactory'

    @abstractmethod
    def createInstanceWithArgumentsAndContext(self, ServiceSpecifier: str, Arguments: 'typing.Tuple[object, ...]', Context: 'XComponentContext_e2e10d4a') -> 'XInterface_8f010a43':
        """
        Creates an instance of a component which supports the services specified by the factory, and initializes the new instance with the given arguments and context.

        Raises:
            com.sun.star.uno.Exception: ``Exception``
        """
        ...
    @abstractmethod
    def createInstanceWithContext(self, aServiceSpecifier: str, Context: 'XComponentContext_e2e10d4a') -> 'XInterface_8f010a43':
        """
        Creates an instance of a component which supports the services specified by the factory.

        Raises:
            com.sun.star.uno.Exception: ``Exception``
        """
        ...
    @abstractmethod
    def getAvailableServiceNames(self) -> 'typing.Tuple[str, ...]':
        """
        Gets the names of all supported services.
        """
        ...

__all__ = ['XMultiComponentFactory']




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sheet
from ..container.x_enumeration import XEnumeration as XEnumeration_f2180daa

class CellFormatRangesEnumeration(XEnumeration_f2180daa):
    """
    Service Class

    represents an enumeration of equal-formatted cell ranges.

    See Also:
        `API CellFormatRangesEnumeration <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1sheet_1_1CellFormatRangesEnumeration.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sheet'
    __ooo_full_ns__: str = 'com.sun.star.sheet.CellFormatRangesEnumeration'
    __ooo_type_name__: str = 'service'



__all__ = ['CellFormatRangesEnumeration']




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from ...lo.connection.acceptor import Acceptor as Acceptor
from ...lo.connection.already_accepting_exception import AlreadyAcceptingException as AlreadyAcceptingException
from ...lo.connection.connection_setup_exception import ConnectionSetupException as ConnectionSetupException
from ...lo.connection.connector import Connector as Connector
from ...lo.connection.no_connect_exception import NoConnectException as NoConnectException
from ...lo.connection.socket_permission import SocketPermission as SocketPermission
from ...lo.connection.x_acceptor import XAcceptor as XAcceptor
from ...lo.connection.x_connection import XConnection as XConnection
from ...lo.connection.x_connection2 import XConnection2 as XConnection2
from ...lo.connection.x_connection_broadcaster import XConnectionBroadcaster as XConnectionBroadcaster
from ...lo.connection.x_connector import XConnector as XConnector



# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.ucb
from enum import IntEnum
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    from ooo.helper.enum_helper import UnoConstMeta, ConstEnumMeta

    class RuleOperator(metaclass=UnoConstMeta, type_name="com.sun.star.ucb.RuleOperator", name_space="com.sun.star.ucb"):
        """Dynamic Class. Contains all the constant values of ``com.sun.star.ucb.RuleOperator``"""
        pass

    class RuleOperatorEnum(IntEnum, metaclass=ConstEnumMeta, type_name="com.sun.star.ucb.RuleOperator", name_space="com.sun.star.ucb"):
        """Dynamic Enum. Contains all the constant values of ``com.sun.star.ucb.RuleOperator`` as Enum values"""
        pass

else:
    from ...lo.ucb.rule_operator import RuleOperator as RuleOperator

    class RuleOperatorEnum(IntEnum):
        """
        Enum of Const Class RuleOperator

        These are the possible values for RuleTerm.RuleOperator.
        """
        CONTAINS = RuleOperator.CONTAINS
        """
        \"Contains\" - Object contains RuleTerm.Operand.
        """
        CONTAINSNOT = RuleOperator.CONTAINSNOT
        """
        \"ContainsNot\" - Object does not contain RuleTerm.Operand.
        """
        GREATEREQUAL = RuleOperator.GREATEREQUAL
        """
        \"GreaterEqual\" - Object is greater than or equal to RuleTerm.Operand.
        """
        LESSEQUAL = RuleOperator.LESSEQUAL
        """
        \"LessEqual\" - Object is less than or equal to RuleTerm.Operand.
        """
        EQUAL = RuleOperator.EQUAL
        """
        \"Equal\" - Object is equal to RuleTerm.Operand.
        """
        NOTEQUAL = RuleOperator.NOTEQUAL
        """
        \"NotEqual\" - Object is not equal to RuleTerm.Operand.
        """
        VALUE_TRUE = RuleOperator.VALUE_TRUE
        """
        \"True\" - Object has the value TRUE.
        """
        VALUE_FALSE = RuleOperator.VALUE_FALSE
        """
        \"False\" - Object has the value FALSE.
        """

__all__ = ['RuleOperator', 'RuleOperatorEnum']



# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sheet
from abc import abstractmethod
from ..container.x_name_container import XNameContainer as XNameContainer_cb90e47

class XSpreadsheets(XNameContainer_cb90e47):
    """
    provides methods to access the spreadsheets by name and to insert, copy, remove and rearrange spreadsheets.

    See Also:
        `API XSpreadsheets <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1sheet_1_1XSpreadsheets.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sheet'
    __ooo_full_ns__: str = 'com.sun.star.sheet.XSpreadsheets'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.sheet.XSpreadsheets'

    @abstractmethod
    def copyByName(self, aName: str, aCopy: str, nDestination: int) -> None:
        """
        copies a sheet within the collection.
        """
        ...
    @abstractmethod
    def insertNewByName(self, aName: str, nPosition: int) -> None:
        """
        inserts a new sheet into the collection.
        """
        ...
    @abstractmethod
    def moveByName(self, aName: str, nDestination: int) -> None:
        """
        moves a sheet within the collection.
        """
        ...

__all__ = ['XSpreadsheets']




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.rendering
from enum import IntEnum
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    from ooo.helper.enum_helper import UnoConstMeta, ConstEnumMeta

    class PathCapType(metaclass=UnoConstMeta, type_name="com.sun.star.rendering.PathCapType", name_space="com.sun.star.rendering"):
        """Dynamic Class. Contains all the constant values of ``com.sun.star.rendering.PathCapType``"""
        pass

    class PathCapTypeEnum(IntEnum, metaclass=ConstEnumMeta, type_name="com.sun.star.rendering.PathCapType", name_space="com.sun.star.rendering"):
        """Dynamic Enum. Contains all the constant values of ``com.sun.star.rendering.PathCapType`` as Enum values"""
        pass

else:
    from ...lo.rendering.path_cap_type import PathCapType as PathCapType

    class PathCapTypeEnum(IntEnum):
        """
        Enum of Const Class PathCapType

        These constants determine which shape to use for start or end of a stroked path.
        
        The start and end of stroked paths can have one out of several different shapes (which are, of course, only visible for strokes wider than one device pixel).
        
        **since**
        
            OOo 2.0
        """
        BUTT = PathCapType.BUTT
        """
        End the path at its start or end point, without any cap.
        """
        ROUND = PathCapType.ROUND
        """
        Extend the path with a half circle cap, diameter is the line width.
        """
        SQUARE = PathCapType.SQUARE
        """
        Extend the path with a rectangular cap, half the line width long.
        """

__all__ = ['PathCapType', 'PathCapTypeEnum']



# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.chart
from .chart_axis_x_supplier import ChartAxisXSupplier as ChartAxisXSupplier_a950e4d
from .chart_axis_z_supplier import ChartAxisZSupplier as ChartAxisZSupplier_aa70e4f
from .chart_statistics import ChartStatistics as ChartStatistics_e2190d37
from .chart_two_axis_y_supplier import ChartTwoAxisYSupplier as ChartTwoAxisYSupplier_380d0f88
from .diagram import Diagram as Diagram_844409cf
from .dim3_d_diagram import Dim3DDiagram as Dim3DDiagram_b7a60b60
from .stackable_diagram import StackableDiagram as StackableDiagram_ee760d59

class AreaDiagram(ChartAxisXSupplier_a950e4d, ChartAxisZSupplier_aa70e4f, ChartStatistics_e2190d37, ChartTwoAxisYSupplier_380d0f88, Diagram_844409cf, Dim3DDiagram_b7a60b60, StackableDiagram_ee760d59):
    """
    Service Class

    This is a service for area diagrams.

    See Also:
        `API AreaDiagram <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1chart_1_1AreaDiagram.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.chart'
    __ooo_full_ns__: str = 'com.sun.star.chart.AreaDiagram'
    __ooo_type_name__: str = 'service'



__all__ = ['AreaDiagram']




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.drawing
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .arrangement import Arrangement as Arrangement_c9be0c68
    from .x_shape import XShape as XShape_8fd00a3d
    from .x_shapes import XShapes as XShapes_9a800ab0

class XShapeArranger(XInterface_8f010a43):
    """
    Objects implementing this interface can be used to arrange Shapes.
    
    .. deprecated::
    
        Class is deprecated.

    See Also:
        `API XShapeArranger <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1drawing_1_1XShapeArranger.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.drawing'
    __ooo_full_ns__: str = 'com.sun.star.drawing.XShapeArranger'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.drawing.XShapeArranger'

    @abstractmethod
    def arrange(self, xShapes: 'XShapes_9a800ab0', eType: 'Arrangement_c9be0c68') -> None:
        """
        applies the specified Arrangement to the specified collection of Shapes.
        """
        ...
    @abstractmethod
    def bringToFront(self, xShapes: 'XShapes_9a800ab0', nSteps: int) -> None:
        """
        moves the specified Shapes by a specified number of objects more to the front.
        """
        ...
    @abstractmethod
    def reverseOrder(self, xShapes: 'XShapes_9a800ab0') -> None:
        """
        reverses the order of the specified collection of Shapes.
        """
        ...
    @abstractmethod
    def sendToBack(self, xShapes: 'XShapes_9a800ab0', nSteps: int) -> None:
        """
        moves the specified Shapes nSteps objects more to the back.
        """
        ...
    @abstractmethod
    def setBehindShape(self, xShapes: 'XShapes_9a800ab0', xShape: 'XShape_8fd00a3d') -> None:
        """
        moves the specified collection of Shapes behind the specified single Shape.
        """
        ...
    @abstractmethod
    def setInFrontOf(self, xShapes: 'XShapes_9a800ab0', xShape: 'XShape_8fd00a3d') -> None:
        """
        moves the specified collection of Shapes in front of the specified single Shape.
        """
        ...

__all__ = ['XShapeArranger']

